Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(100)

Unified Diff: net/base/net_util.h

Issue 9317018: referrer_charset is a lie. It's really the user's default_charset. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/shell_download_manager_delegate.cc ('k') | net/base/net_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/net_util.h
===================================================================
--- net/base/net_util.h (revision 119865)
+++ net/base/net_util.h (working copy)
@@ -134,7 +134,7 @@
// TODO(abarth): Move these functions to http_content_disposition.cc.
bool DecodeFilenameValue(const std::string& input,
- const std::string& referrer_charset,
+ const std::string& default_charset,
std::string* output);
bool DecodeExtValue(const std::string& value, std::string* output);
@@ -209,11 +209,11 @@
// order):
//
// 1) The raw Content-Disposition header in |content_disposition| (as read from
// the network. |referrer_charset| is used as described in the comment for
// GetFileNameFromCD().
// 2) |suggested_name| if specified. |suggested_name| is assumed to be in
// UTF-8.
// 3) The filename extracted from the |url|. |referrer_charset| will be used to
// interpret the URL if there are non-ascii characters.
// 4) |default_name|. If non-empty, |default_name| is assumed to be a filename
// and shouldn't contain a path. |default_name| is not subject to validation
@@ -235,7 +235,7 @@
// thread that allows IO.
NET_EXPORT string16 GetSuggestedFilename(const GURL& url,
const std::string& content_disposition,
- const std::string& referrer_charset,
+ const std::string& default_charset,
const std::string& suggested_name,
const std::string& mime_type,
const std::string& default_name);
@@ -243,7 +243,7 @@
// Similar to GetSuggestedFilename(), but returns a FilePath.
NET_EXPORT FilePath GenerateFileName(const GURL& url,
const std::string& content_disposition,
- const std::string& referrer_charset,
+ const std::string& default_charset,
const std::string& suggested_name,
const std::string& mime_type,
const std::string& default_name);
@@ -209,11 +209,11 @@
//
// 1) The raw Content-Disposition header in |content_disposition| (as read from
-// the network. |referrer_charset| is used as described in the comment for
+// the network. |default_charset| is used as described in the comment for
// GetFileNameFromCD().
// 2) |suggested_name| if specified. |suggested_name| is assumed to be in
@@ -209,11 +209,11 @@
// 2) |suggested_name| if specified. |suggested_name| is assumed to be in
// UTF-8.
-// 3) The filename extracted from the |url|. |referrer_charset| will be used to
+// 3) The filename extracted from the |url|. |default_charset| will be used to
// interpret the URL if there are non-ascii characters.
// 4) |default_name|. If non-empty, |default_name| is assumed to be a filename
« no previous file with comments | « content/shell/shell_download_manager_delegate.cc ('k') | net/base/net_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698